@@ -15,8 +15,6 @@
 #' @param fail_on_error   If an error occurs on the workers, continue or fail?
 #' @param workers         Optional instance of QSys representing a worker pool
 #' @param log_worker      Write a log file for each worker
-#' @param wait_time       Time to wait between messages; set 0 for short calls
-#'                        defaults to 1/sqrt(number_of_functon_calls)
 #' @param chunk_size      Number of function calls to chunk together
 #'                        defaults to 100 chunks per worker or max. 10 kb per chunk
 #' @param timeout         Maximum time in seconds to wait for worker (default: Inf)
@@ -38,7 +36,7 @@
 Q = function(fun, ..., const=list(), export=list(), seed=128965,
         memory=NULL, template=list(), n_jobs=NULL, job_size=NULL,
         split_array_by=-1, rettype="list", fail_on_error=TRUE, workers=NULL,
-        log_worker=FALSE, wait_time=NA, chunk_size=NA, timeout=Inf) {
+        log_worker=FALSE, chunk_size=NA, timeout=Inf) {
 
     split_arrays = function(x) {
         if (is.array(x))
@@ -62,7 +60,6 @@ Q = function(fun, ..., const=list(), export=list(), seed=128965,
            fail_on_error = fail_on_error,
            workers = workers,
            log_worker = log_worker,
-           wait_time = wait_time,
            chunk_size = chunk_size,
            timeout = timeout)
 }
