@@ -3,6 +3,8 @@
 #' Provides the basic functions needed to communicate between machines
 #' This should abstract most functions of rZMQ so the scheduler
 #' implementations can rely on the higher level functionality
+#'
+#' @keywords internal
 QSys = R6::R6Class("QSys",
     public = list(
         # Create a class instance
@@ -105,13 +107,17 @@ QSys = R6::R6Class("QSys",
 
             if (rcv[[1]]$read) { # otherwise timeout reached
                 msg = rzmq::receive.socket(private$socket)
+
+                if (private$auth != "" && (is.null(msg$auth) || msg$auth != private$auth))
+                    stop("Authentication provided by worker does not match")
+
                 switch(msg$id,
                     "WORKER_UP" = {
                         if (!is.null(private$pkg_warn) && msg$pkgver != private$pkg_warn) {
                             warning("\nVersion mismatch: master has ", private$pkg_warn,
                                     ", worker ", msg$pkgver, immediate.=TRUE)
-                            private$pkg_warn = NULL
                         }
+                        private$pkg_warn = NULL
                         msg$id = "WORKER_READY"
                         msg$token = "not set"
                         private$workers_up = private$workers_up + 1
@@ -192,6 +198,7 @@ QSys = R6::R6Class("QSys",
         defaults = list(),
         is_cleaned_up = FALSE,
         pkg_warn = utils::packageVersion("clustermq"),
+        auth = "",
 
         send = function(..., serialize=TRUE) {
             rzmq::send.socket(socket = private$socket,
@@ -209,6 +216,13 @@ QSys = R6::R6Class("QSys",
         fill_options = function(...) {
             values = utils::modifyList(private$defaults, list(...))
             values$master = private$master
+            if ("auth" %in% names(infuser::variables_requested(private$template))) {
+                values$auth = private$auth = paste(sample(letters, 5, TRUE), collapse="")
+            } else {
+                values$auth = NULL
+                warning("Add 'CMQ_AUTH={{ auth }}' to template to enable socket authentication",
+                        immediate.=TRUE)
+            }
             if (!"job_name" %in% names(values))
                 values$job_name = paste0("cmq", private$port)
             private$workers_total = values$n_jobs
@@ -216,6 +230,8 @@ QSys = R6::R6Class("QSys",
         },
 
         fill_template = function(values) {
+            # note: auth will be obligatory in the future and this check will
+            #   be removed (i.e., filling will fail if no field in template)
             infuser::infuse(private$template, values)
         },
 
